.. -*-restructuredtext-*-

This application provids simple, extensible contact-form functionality
for `Django <https://www.djangoproject.com/>`_ sites.

Full documentation for all functionality is included and is also
`available online <http://django-contact-form.readthedocs.org/>`_.